@@ -1,12 +1,12 @@
 #! /bin/sh -e
-# /usr/lib/emacsen-common/packages/install/skidstone
+# /usr/lib/emacsen-common/packages/install/skidstone-0.1.3
 
 # Written by Jim Van Zandt <jrv@debian.org>, borrowing heavily
 # from the install scripts for gettext by Santiago Vila
 # <sanvila@ctv.es> and octave by Dirk Eddelbuettel <edd@debian.org>.
 
 FLAVOR=$1
-PACKAGE=skidstone
+PACKAGE=skidstone-0.1.3
 
 if [ ${FLAVOR} = emacs ]; then exit 0; fi
 
