@@ -1,13 +1,13 @@
 #!/bin/sh -e
-# /usr/lib/emacsen-common/packages/remove/skidstone
+# /usr/lib/emacsen-common/packages/remove/skidstone-0.1.3
 
 FLAVOR=$1
-PACKAGE=skidstone
+PACKAGE=skidstone-0.1.3
 
 if [ ${FLAVOR} != emacs ]; then
     if test -x /usr/sbin/install-info-altdir; then
         echo remove/${PACKAGE}: removing Info links for ${FLAVOR}
-        install-info-altdir --quiet --remove --dirname=${FLAVOR} /usr/share/info/skidstone.info.gz
+        install-info-altdir --quiet --remove --dirname=${FLAVOR} /usr/share/info/skidstone-0.1.3.info.gz
     fi
 
     echo remove/${PACKAGE}: purging byte-compiled files for ${FLAVOR}
