@@ -1,25 +1,25 @@
 ;; -*-emacs-lisp-*-
 ;;
-;; Emacs startup file, e.g.  /etc/emacs/site-start.d/50skidstone.el
-;; for the Debian skidstone package
+;; Emacs startup file, e.g.  /etc/emacs/site-start.d/50skidstone-0.1.3.el
+;; for the Debian skidstone-0.1.3 package
 ;;
 ;; Originally contributed by Nils Naumann <naumann@unileoben.ac.at>
 ;; Modified by Dirk Eddelbuettel <edd@debian.org>
 ;; Adapted for dh-make by Jim Van Zandt <jrv@debian.org>
 
-;; The skidstone package follows the Debian/GNU Linux 'emacsen' policy and
+;; The skidstone-0.1.3 package follows the Debian/GNU Linux 'emacsen' policy and
 ;; byte-compiles its elisp files for each 'emacs flavor' (emacs19,
 ;; xemacs19, emacs20, xemacs20...).  The compiled code is then
 ;; installed in a subdirectory of the respective site-lisp directory.
 ;; We have to add this to the load-path:
 (let ((package-dir (concat "/usr/share/"
                            (symbol-name flavor)
-                           "/site-lisp/skidstone")))
-;; If package-dir does not exist, the skidstone package must have
+                           "/site-lisp/skidstone-0.1.3")))
+;; If package-dir does not exist, the skidstone-0.1.3 package must have
 ;; removed but not purged, and we should skip the setup.
   (when (file-directory-p package-dir)
         (setq load-path (cons package-dir load-path))
-       (autoload 'skidstone-mode "skidstone-mode"
-         "Major mode for editing skidstone files." t)
-       (add-to-list 'auto-mode-alist '("\\.skidstone$" . skidstone-mode))))
+       (autoload 'skidstone-0.1.3-mode "skidstone-0.1.3-mode"
+         "Major mode for editing skidstone-0.1.3 files." t)
+       (add-to-list 'auto-mode-alist '("\\.skidstone-0.1.3$" . skidstone-0.1.3-mode))))
 
