@@ -26,9 +26,7 @@ gameScene::gameScene(bool newGame, QObject *parent)
     this->setSceneRect(-400, -240, 800, 480);
     QPixmap bgPix(":/img/game_back.png");
     QGraphicsItem *item = this->addPixmap(bgPix);
-//    item->setZValue(0);
     item->setPos(-400,-240);
-//    this->setBackgroundBrush(bgPix);
 
     qsrand(QTime(0,0,0).secsTo(QTime::currentTime())); // init randomize
     m_levelDat.resize(81);
@@ -45,16 +43,8 @@ gameScene::gameScene(bool newGame, QObject *parent)
     mb->setPos(358,-208);
     connect(mb,SIGNAL(clicked()),this,SLOT(backCommand()));
 
-/*    QPushButton *pb1 = new QPushButton("Back");
-    QGraphicsProxyWidget *aa = this->addWidget(pb1);
-    aa->setPos(330, -240);
-    connect(pb1,SIGNAL(clicked()),this,SLOT(backCommand()));
-*/
-
     QPixmap buttonPix1(":/img/level.png");
     item = this->addPixmap(buttonPix1);
-//    QFont font;
-//    QGraphicsItem *item = this->addText("Level", font);
     int ix = buttonPix1.width()/2;
     item->setZValue(5);
     item->setPos(250 - ix, 100);
@@ -65,14 +55,9 @@ gameScene::gameScene(bool newGame, QObject *parent)
     _wLevel->setPos(250, 160);
     _wLevel->setNumber(1);
 
-/*    m_levelLabel= new QLabel("unknown");
-    QGraphicsProxyWidget *aa = this->addWidget(m_levelLabel);
-    aa->setPos(200, 150);
-*/
     loadScores();
     QPixmap buttonPix2(":/img/score.png");
     item = this->addPixmap(buttonPix2);
-//    item = this->addText("Score", font);
     item->setZValue(5);
     ix = buttonPix2.width()/2;
     item->setPos(250 - ix, -60);
@@ -83,13 +68,8 @@ gameScene::gameScene(bool newGame, QObject *parent)
     _wScore->setPos(250, 0);
     _wScore->setNumber(0);
 
-/*    m_scoreLabel= new QLabel("000000");
-    QGraphicsProxyWidget *aa = this->addWidget(m_scoreLabel);
-    aa->setPos(200, 50);
-*/
     QPixmap buttonPix3(":/img/t_score.png");
     item = this->addPixmap(buttonPix3);
-//    item = this->addText("Hi-Score", font);
     item->setZValue(5);
     ix = buttonPix3.width()/2;
     item->setPos(250 - ix, -160);
@@ -99,10 +79,6 @@ gameScene::gameScene(bool newGame, QObject *parent)
     _wTScore->setZValue(5);
     _wTScore->setPos(250, -100);
     _wTScore->setNumber(m_topScore);
-/*    m_topScoreLabel= new QLabel(QString::number(m_topScore));
-    aa = this->addWidget(m_topScoreLabel);
-    aa->setPos(200, -50);
-*/
 
     #if defined(Q_WS_MAEMO_5)
         QPixmap buttonPix6(":/img/desk.png");
@@ -146,7 +122,6 @@ void gameScene::loadScores()
     }
     else
       m_topScore = 10000;
-//        m_topScore = 100;
 }
 
 void gameScene::saveScores()
@@ -163,7 +138,6 @@ void gameScene::saveScores()
 
 void gameScene::gnerateField()
 {
-//    m_colorNumber = 5;
     currentLevel = 1;
     readLevel();     // read 1st level data
 
@@ -181,7 +155,6 @@ void gameScene::gnerateField()
         // box tiles
         else if ((i < 10) || (i > 110) || (i%11 == 0) || ((i-10)%11 == 0))
         {
-//            item = new BoxWidget(Qt::GlobalColor(qrand() % m_colorNumber + 7));
             item = new BoxWidget(qrand() % m_colorNumber + 1);
             item->setBoxTile(true);
             item->setColorNumber(m_colorNumber);
@@ -198,20 +171,15 @@ void gameScene::gnerateField()
 
 void gameScene::loadField()
 {
-//    QString fileName = QString(CFG_DIR) + QString(STATE_FILE);
     QFile file(m_datFileName);
     QDataStream in(&file);
     BoxWidget *item;
     if (file.open(QIODevice::ReadOnly))
     {
         in >> currentLevel;
-//        QString labelText = QString("%1").arg(QString::number(currentLevel));
-//        m_levelLabel->setText(labelText);
         _wLevel->setNumber(currentLevel);
         in >> m_colorNumber;
         in >> m_score;
-//        QString labelText = QString("%1").arg(QString::number(m_score));
-//        m_scoreLabel->setText(labelText);
         _wScore->setNumber(m_score);
         for (int i = 0; i < 121; ++i) {
             item = new BoxWidget();
@@ -282,10 +250,9 @@ void gameScene::sceneInit()
             trans = c13->addTransition(c13, SIGNAL(propertiesAssigned()), c11);
             anim = new QPropertyAnimation(item, "pos");
             anim->setEasingCurve(QEasingCurve::OutBounce);
-            anim->setDuration(750);
+            anim->setDuration(600); // was 750
             trans->addAnimation(anim);
 
-//            connect(item, SIGNAL(fired(QPointF, QPointF,QColor)), this, SLOT(boxFired(QPointF, QPointF,QColor)));
             connect(item, SIGNAL(fired(QPointF, QPointF,int)), this, SLOT(boxFired(QPointF, QPointF,int)));
         }
         // field tiles
@@ -333,10 +300,7 @@ void gameScene::sceneInit()
     connect(&m_timerColor, SIGNAL(timeout()), this,SLOT(checkColor()));
     connect(&m_timerField, SIGNAL(timeout()), this,SLOT(setFieldBoxes2()));
     connect(&m_timerFieldCheck, SIGNAL(timeout()), this,SLOT(checkBuddyColors()));
-//    connect(s1,SIGNAL(propertiesAssigned()),this,SLOT(statesInitialized()));
     connect(s1,SIGNAL(propertiesAssigned()),this,SLOT(setFieldBoxes()));
-//    connect(s1,SIGNAL(propertiesAssigned()),this,SLOT(tileTransform()));
-
 
     // init moving block
     m_movingBox = new BoxWidget(Qt::black);
@@ -351,7 +315,7 @@ void gameScene::sceneInit()
     QAbstractTransition *trans = m_mb1->addTransition(this, SIGNAL(moveTile()), m_mb2);
     trans = m_mb2->addTransition(m_mb2, SIGNAL(propertiesAssigned()), m_mb3);
     QPropertyAnimation *anim = new QPropertyAnimation(m_movingBox, "pos");
-    anim->setDuration(750);
+    anim->setDuration(600); // was 750
     anim->setEasingCurve(QEasingCurve::InOutCubic);
     trans->addAnimation(anim);
     trans = m_mb3->addTransition(m_mb3, SIGNAL(propertiesAssigned()), m_mb1);
@@ -360,11 +324,6 @@ void gameScene::sceneInit()
     this->addItem(m_movingBox);
     m_movingBox->setZValue(3);
 
-/*    QPixmap bgPix(":/img/back1.png");
-    QGraphicsPixmapItem *bgItem = this->addPixmap(bgPix);
-    bgItem->setZValue(0);
-    bgItem->setPos(-SHIFT_LEFT-BOX_SIZE/2-4, -SHIFT_TOP-BOX_SIZE/2-4);
-*/
     // state machine
     m_states.addState(s1);
     m_states.setInitialState(s1);
@@ -372,7 +331,6 @@ void gameScene::sceneInit()
 }
 
 // calculate coord in matrix using Box Coordinate
-//void gameScene::boxFired(QPointF aPos, QPointF aPoint, QColor aColor)
 void gameScene::boxFired(QPointF aPos, QPointF aPoint, int aColor)
 {
     disableMove();
@@ -385,12 +343,6 @@ void gameScene::boxFired(QPointF aPos, QPointF aPoint, int aColor)
     emit moveTile();
 }
 
-// trick to avoid multiple CheckField before all been initialized
-//void gameScene::statesInitialized()
-//{
-  //  setFieldBoxes();
-//}
-
 void gameScene::tile2boxAssign(BoxWidget *aTile)
 {
     QState *s1 = aTile->stateWay();
@@ -410,11 +362,11 @@ void gameScene::tileTransform()
     }
     emit tile2box();
     if (m_xBox > 0)
-        m_timerColor.start(50);
+        m_timerColor.start(50); // was 50
     else
     {
         m_initState = false;
-        m_timerFieldCheck.start(50); // goto check buddy colors
+        m_timerFieldCheck.start(50); //was 50 // goto check buddy colors
     }
  }
 
@@ -424,20 +376,16 @@ bool gameScene::checkBuddy(int aPos, int aColor)
     BoxWidget *byddyTile = m_items.at(aPos);
     if (byddyTile->isBoxTile())
     {
-//        QColor buddyColor = byddyTile->iColor();
         int buddyColor = byddyTile->iColor();
         if (aColor == buddyColor)
         {
-     //       byddyTile->setBoxTile(false);
             QState *s1 = byddyTile->stateBox();
             QState *s2 = byddyTile->stateWay();
             QAbstractTransition *trans = s1->addTransition(this, SIGNAL(box2tile()), s2);
             QPropertyAnimation *anim = new QPropertyAnimation(byddyTile, "opacity");
-            anim->setDuration(750);
+            anim->setDuration(500); // was 750
             trans->addAnimation(anim);
             byddyTile->setTransition(trans,2,1);
-//            connect(s2,SIGNAL(propertiesAssigned()),byddyTile,SLOT(transitionFinishedBox()));
-//            connect(s2,SIGNAL(propertiesAssigned()),this,SLOT(cleanField()));
             return true;
         }
     }
@@ -450,7 +398,6 @@ void gameScene::checkColor()
     m_initState = false;
     bool coincidence = false;
     BoxWidget *boxTile = m_items.at(m_xBox);
-//    QColor boxColor = boxTile->iColor();
     int boxColor = boxTile->iColor();
     int ix = m_xBox - 11;
     int dels = 0; // count deleted boxes for score
@@ -496,22 +443,17 @@ void gameScene::checkColor()
     if (coincidence)
     {
         dels ++;
-//        boxTile->setBoxTile(false);
         QState *s1 = boxTile->stateBox();
         QState *s2 = boxTile->stateWay();
         QAbstractTransition *trans = s1->addTransition(this, SIGNAL(box2tile()), s2);
         QPropertyAnimation *anim = new QPropertyAnimation(boxTile, "opacity");
-        anim->setDuration(750);
+        anim->setDuration(500); // was 750
         trans->addAnimation(anim);
         boxTile->setTransition(trans,2,1);
-//        connect(s2,SIGNAL(propertiesAssigned()),boxTile,SLOT(transitionFinishedBox()));
-//        connect(s2,SIGNAL(propertiesAssigned()),this,SLOT(cleanField()));
         emit box2tile();
-        m_timer.start(800);
+        m_timer.start(550);
 
         m_score += dels * 5 * m_prevDel;
-//        QString labelText = QString("%1").arg(QString::number(m_score));
-//        m_scoreLabel->setText(labelText);
         _wScore->setNumber(m_score);
         m_prevDel ++;
     }
@@ -536,15 +478,11 @@ void gameScene::cleanField()
                 tile->setWayTile(false);
                 QState *s1 = tile->stateWay();
                 QState *s2 = tile->stateBack();
-//                    s2->assignProperty(tile,"color",m_xColor);
                 QAbstractTransition *trans = s1->addTransition(this, SIGNAL(cleantile()), s2);
                 tile->setTransition(trans,1,3);
-//                connect(s2,SIGNAL(propertiesAssigned()),tile,SLOT(transitionFinishedWay2Back()));
             }
     }
     emit cleantile();
-//    m_initState = false;
-//    m_timerColor.start(50);
     checkField();
 }
 
@@ -562,15 +500,6 @@ void gameScene::checkField()
 
         BoxWidget *tile = m_items.at(i);
 
-/*        if (((i < 21) && (i > 11))
-            || ((i > 99) && (i < 109))
-            || ((x == 1) && (i < 109) && (i > 11))
-            || ((x == 9) && (i < 109) && (i > 11)))
-            {
-            if (!tile->isBoxTile())
-                final = false;
-        }*/
-
         if (((i < 10) && (i > 0))
             || ((i > 110) && (i < 120))
             || ((x == 0) && (i != 110))
@@ -620,13 +549,8 @@ void gameScene::checkField()
                     BoxWidget *tile = m_items.at(x+y*11);
                     QState *s1 = tile->stateBack();
                     QState *s2 = tile->stateWay();
-//                    s2->assignProperty(tile,"color",m_xColor);
                     QAbstractTransition *trans = s1->addTransition(this, SIGNAL(tile2way()), s2);
                     tile->setTransition(trans,3,1);
-//                    connect(s2,SIGNAL(propertiesAssigned()),tile,SLOT(transitionFinished2Way()));
-//                    connect(s2,SIGNAL(propertiesAssigned()),this,SLOT(checkColor()));
-                //    connect(m_stateBack,SIGNAL(propertiesAssigned()),this,SLOT(transitionFinishedBack()));
-//                    tile->setWayTile(true);
                 }
             }
             else
@@ -670,11 +594,6 @@ void gameScene::startGameOver()
     QFile file(m_datFileName);
     file.remove();
     // show message
-//    QFont font;
-//    fnt.setFamily(Qt::AnchorVerticalCenter);
-//    QGraphicsTextItem  *text = this->addText("Game over", font);
-//    text->setZValue(10);
-//    text->setPos(-100,-10);
 
     if (m_topScore < m_score)
     {
@@ -715,7 +634,6 @@ void gameScene::renewField()
     for (int i=1;i<120;++i)
     {
         int x = i%11;
-//        int y = i/11;
         if (((i < 10) && (i > 0))
             || ((i > 110) && (i < 120))
             || ((x == 0) && (i != 110))
@@ -723,12 +641,10 @@ void gameScene::renewField()
         {
             BoxWidget *tile = m_items.at(i);
             tile->setColorNumber(m_colorNumber);
-//            tile->setIColor(Qt::transparent);
             tile->setIColor(0);
         }
     }
     setFieldBoxes();
-//    tileTransform();
 }
 
 void gameScene::setFieldBoxes()
@@ -748,7 +664,7 @@ void gameScene::setFieldBoxes()
         }
     }
     emit tile2way();
-    m_timerField.start(50);
+    m_timerField.start(50); // was 50
 }
 
 
@@ -763,7 +679,6 @@ void gameScene::setFieldBoxes2()
         if (m_levelDat.testBit(y))
         {
             BoxWidget *tile = m_items.at(x);
-//            m_xColor = Qt::GlobalColor(qrand() % m_colorNumber + 7);
             m_xColor = qrand() % m_colorNumber + 1;
             tile2boxAssign(tile);
         }
@@ -773,8 +688,6 @@ void gameScene::setFieldBoxes2()
 
 void gameScene::readLevel()
 {
-//    QString labelText = QString("%1").arg(QString::number(currentLevel));
-//    m_levelLabel->setText(labelText);
     _wLevel->setNumber(currentLevel);
 
     QString fileName = QString(":/levels/%1.dat").arg(QString::number(currentLevel));
@@ -799,12 +712,9 @@ void gameScene::checkBuddyColors()
         BoxWidget *tile = m_items.at(x);
         if (tile->isBoxTile())
         {
-//            QColor boxColor = tile->iColor();
             int boxColor = tile->iColor();
-//            QColor boxRight;
             int boxRight;
             BoxWidget *tileR;
-//            QColor boxDown;
             int boxDown;
             BoxWidget *tileD;
             x1 = x + 1;
@@ -816,7 +726,6 @@ void gameScene::checkBuddyColors()
                     boxRight = tileR->iColor();
                     while (boxColor == boxRight) // need to change color
                     {
-//                       boxRight = Qt::GlobalColor(qrand() % m_colorNumber + 7);
                        boxRight = 0;
                     }
                     tileR->setIColor(boxRight);
@@ -832,7 +741,6 @@ void gameScene::checkBuddyColors()
                     boxDown = tileD->iColor();
                     while (boxColor == boxDown) // need to change color
                     {
-//                       boxDown = Qt::GlobalColor(qrand() % m_colorNumber + 7);
                        boxDown = 0;
                     }
                     tileD->setIColor(boxDown);
@@ -840,18 +748,16 @@ void gameScene::checkBuddyColors()
             }
         }
     }
-    m_timer.start(50); // goto CleanField
+    m_timer.start(50); //was 50 // goto CleanField
 }
 
 void gameScene::backCommand()
 {
-//    saveState();
     emit backButtonClicked();
 }
 
 void gameScene::saveState()
 {
-//    QString fileName = CFG_DIR + STATE_FILE;
     QFile file(m_datFileName);
     QDataStream out(&file);
     BoxWidget *item;
