@@ -4,6 +4,14 @@
 #include "menuscene.h"
 #include "maekerstartview.h"
 
+// Needed Symbian specific headers
+#ifdef Q_OS_SYMBIAN
+#include <eikenv.h>
+#include <eikappui.h>
+#include <aknenv.h>
+#include <aknappui.h>
+#endif
+
 int main(int argc, char *argv[])
 {
     QApplication a(argc, argv);
@@ -13,17 +21,23 @@ int main(int argc, char *argv[])
 //    MaeKerlingView *view = new MaeKerlingView(&scene, viewIntro);
 //    view->setMainView(viewIntro);
 //    viewIntro->setGameView(view);
-#if defined(Q_WS_S60)
-    viewIntro->showMaximized();
-//    view->showMaximized()
+#ifdef Q_OS_SYMBIAN
+    CAknAppUi* appUi = dynamic_cast<CAknAppUi*> (CEikonEnv::Static()->AppUi());
+    TRAPD(error,
+    if (appUi) {
+        // Lock application orientation into landscape
+        appUi->SetOrientationL(CAknAppUi::EAppUiOrientationLandscape);
+    }
+    );
+    viewIntro->showFullScreen();
 #elif defined(Q_WS_MAEMO_5)
 //    QResource::registerResource("/opt/skidstone/skidstone.rcc","/");
 //    view->setWindowFlags(Qt::FramelessWindowHint);
   //  view->setGeometry(Qrect(0,0,800,480));
-    //view->showFullScreen();
+    viewIntro->showFullScreen();
 //     setWindowFlags(Qt::FramelessWindowHint);
 //    viewIntro->setGeometry(QRect(0,0,800,480));
-    viewIntro->showFullScreen();
+//    viewIntro->showNormal();
 #else
 //    view->setWindowFlags(Qt::FramelessWindowHint);
   //  view->setGeometry(Qrect(0,0,800,480));
